from contextlib import asynccontextmanager

from fastapi import FastAPI

from .routers.auth import router as auth_router
from .routers.user import router as user_router


@asynccontextmanager
async def lifespan(app: FastAPI):
    print("Lifespan init")
    yield
    print("Lifespan exited")


def create_app() -> FastAPI:
    app = FastAPI(lifespan=lifespan)
    app.include_router(user_router)
    app.include_router(auth_router)
    return app
