import os
from functools import lru_cache

import yaml  # type: ignore
from pydantic_settings import BaseSettings

SECRET_KEY = "09d25e094faa6ca2556c818166b7a9563b93f7099f6f0f4caa6cf63b88e8d3e7"
ALGORITHM = "HS256"
ACCESS_TOKEN_EXPIRE_MINUTES = 30


class DBSettings(BaseSettings):
    pg_user: str
    pg_pass: str
    pg_host: str
    pg_port: int
    pg_db: str

    @property
    def get_db_url(self) -> str:
        return "postgresql+asyncpg://{}:{}@{}:{}/{}".format(
            self.pg_user,
            self.pg_pass,
            self.pg_host,
            self.pg_port,
            self.pg_db,
        )


class RedisSettings(BaseSettings):
    redis_host: str
    redis_port: int


class Settings(BaseSettings):
    db: DBSettings
    redis: RedisSettings


@lru_cache(maxsize=None)
def get_settings():
    with open(os.getenv("CONFIG_PATH", "./config/api_config.yml")) as f:
        config_data: dict = yaml.safe_load(f)

    settings = Settings(
        db=DBSettings(**config_data["db"]),
        redis=RedisSettings(**config_data["redis"]),
    )

    if os.getenv("INDOCKER"):
        settings.db.pg_host = "db"
        settings.db.pg_port = 5432

    return settings
