from fastapi.security import OAuth2PasswordBearer
from sqlalchemy.ext.asyncio import AsyncSession, async_sessionmaker, create_async_engine

from test_api.services.auth import AuthService

from .config import get_settings
from .services.user import UserService
from .uow.uow_base import UnitOfWork

Oauth2_scheme = OAuth2PasswordBearer(tokenUrl="token")

async_engine = create_async_engine(
    url=get_settings().db.get_db_url,
    echo=False,
)

async_session_factory = async_sessionmaker(
    async_engine,
    class_=AsyncSession,
    expire_on_commit=False,
)

uow = UnitOfWork(
    session_factory=async_session_factory,
)

user_service = UserService(
    uow=uow,
)

auth_service = AuthService(
    uow=uow,
)


def get_user_service():
    return user_service


def get_auth_service():
    return auth_service
